@@ -1,4 +1,4 @@
-from datetime import date as __dt
+from datetime import date as __dt, datetime as __dtime
 from .__errors__ import CommitError as __CErr
 from itertools import permutations as __perm
 from json import load as __load, dumps as __dumps
@@ -234,7 +234,9 @@ def log(value=None, showpath=False):
 	else:
 		if __exs(filename):
 			file = open(filename, "a")
-			file.write("\n\nNew Match\n" + "-"*9 + "\n")
+			time = __dtime.now().strftime("%H:%M:%S")
+			data = f"\n\nNew Match played at {time}\n"
+			file.write(data + "-"*9 + "\n")
 		else:
 			file = open(filename, "w")
 
